package com.onsiteservice.miniapp.service.address;

import com.onsiteservice.entity.address.ServiceAddress;
import com.onsiteservice.miniapp.controller.address.dto.SaveServiceAddressDTO;
import com.onsiteservice.miniapp.controller.address.dto.UpdateServiceAddressDTO;
import com.onsiteservice.miniapp.controller.address.vo.ServiceAddressVO;
import com.onsiteservice.miniapp.mapper.address.ServiceAddressMapper;

import com.onsiteservice.dao.common.AbstractMapper;
import com.onsiteservice.dao.common.page.PageParams;
import com.onsiteservice.dao.common.page.PageInfoVO;
import com.github.pagehelper.PageHelper;
import com.onsiteservice.util.AttrCopyUtils;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import tk.mybatis.mapper.entity.Condition;

import javax.annotation.Resource;

import java.util.List;
import java.util.stream.Collectors;

import static com.onsiteservice.core.result.ResultGenerator.success;

@Service
@Transactional(rollbackFor = Exception.class)
public class ServiceAddressService extends AbstractMapper<ServiceAddress> {

    @Resource
    private ServiceAddressMapper serviceAddressMapper;

    /**
     * 分页查询列表
     */
    public PageInfoVO getPage(PageParams param) {
        PageHelper.startPage(param.getPage(), param.getSize());
        return new PageInfoVO(this.selectAll());
    }


    public ServiceAddressVO selectById(Long id) {
        ServiceAddress serviceAddress = this.selectByPrimaryKey(id);
        return AttrCopyUtils.copy(serviceAddress, new ServiceAddressVO());
    }


    public List<ServiceAddressVO> selectByUserId(Long userId) {
        Condition condition = new Condition(ServiceAddress.class);
        condition.createCriteria().andEqualTo("account_no", userId);
        List<ServiceAddress> serviceAddresses = this.selectByCondition(condition);

        return serviceAddresses.parallelStream()
                .map(e -> AttrCopyUtils.copy(e, new ServiceAddressVO()))
                .collect(Collectors.toList());
    }


    public int save(SaveServiceAddressDTO dto, Long userId) {
        ServiceAddress serviceAddress = AttrCopyUtils.copy(dto, new ServiceAddress());
        serviceAddress.setAccountNo(userId);
        return this.insertSelective(serviceAddress);
    }


    public int update(UpdateServiceAddressDTO dto) {
        ServiceAddress serviceAddress = AttrCopyUtils.copy(dto, new ServiceAddress());
        return this.updateByPrimaryKey(serviceAddress);
    }


}
